This is a Python package that parses a given sql query, matches the column and tables within your given metastore, and analyzes the query to generate a list of referenced columns within the metastore.

[Upload instructions](https://packaging.python.org/tutorials/packaging-projects/)